==> kdeutils-4.1.4.tar.bz2: kdeutils-4.1.4/okteta/program/libkakao/controllers/program/quit/quitcontroller.h <==
/*
    This file is part of the Kakao Framework, part of the KDE project.

    Copyright 2006-2007 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef QUITCONTROLLER_H
#define QUITCONTROLLER_H


// lib
#include <kviewcontroller.h>
// KDE
#include <KUrl>

class KXmlGuiWindow;
class KProgram;


class QuitController : public KViewController
{
  Q_OBJECT

  public:
    QuitController( KProgram *program, KXmlGuiWindow *window );

  public: // KToolet API
    virtual void setView( KAbstractView *view );

  public Q_SLOTS:
    void quit();

  protected:
//     KProgram *Program;
    KXmlGuiWindow *mMainWindow;
};

#endif

==> kdeutils-4.3.2.tar.bz2: kdeutils-4.3.2/okteta/program/libkakao/controllers/program/quit/quitcontroller.h <==
/*
    This file is part of the Kakao Framework, part of the KDE project.

    Copyright 2006-2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef QUITCONTROLLER_H
#define QUITCONTROLLER_H


// lib
#include <abstractxmlguicontroller.h>

class KXmlGuiWindow;
class KProgram;


class QuitController : public AbstractXmlGuiController
{
  Q_OBJECT

  public:
    QuitController( KProgram *program, KXmlGuiWindow *window );

  public: // AbstractXmlGuiController API
    virtual void setTargetModel( AbstractModel* model );

  public Q_SLOTS:
    void quit();

  protected:
//     KProgram *Program;
    KXmlGuiWindow *mMainWindow;
};

#endif
